@@ -3,12 +3,13 @@
 cmake .. \
     -G Ninja \
     -DCMAKE_BUILD_TYPE=Release \
-    -DBUILD_PLUGIN_CPD=OFF \
-    -DBUILD_PLUGIN_I3S=ON \
+    -DBUILD_PLUGIN_CPD=ON \
     -DBUILD_PLUGIN_NITF=OFF \
     -DBUILD_PLUGIN_ICEBRIDGE=ON \
     -DBUILD_PLUGIN_PGPOINTCLOUD=ON \
     -DBUILD_PLUGIN_E57=ON \
     -DBUILD_PGPOINTCLOUD_TESTS=OFF \
-    -DWITH_TESTS=ON
+    -DBUILD_PLUGIN_ARROW=ON \
+    -DBUILD_PLUGIN_TILEDB=ON \
+    -DWITH_TESTS=ON $1
 
